@@ -9,22 +9,13 @@ our @ISA = qw(Exporter);
 
 our @EXPORT_OK = qw(c2xs);
 
-our $VERSION = 0.15;
+our $VERSION = 0.16;
 
-my $config_options =
-       {
-       'AUTOWRAP' => 0,
-       'AUTO_INCLUDE' => '',
-       'LIBS' => [],
-       'VERSION' => 0,
-       'WRITE_MAKEFILE_PL' => 0,
-       'WRITE_PM' => 0,
-       }
-;        
+my $config_options;       
 
 sub c2xs {
     eval {require "Inline/C.pm"};
-    if($@ || $Inline::C::VERSION < 0.45) {die "Need a functioning Inline::C (version 0.45 or later). $@"}
+    if($@) {die "Need a functioning Inline::C (version 0.46_01 or later). $@"}
     my $module = shift;
     my $pkg = shift;
 
@@ -128,6 +119,8 @@ sub c2xs {
 
     if(exists($config_options->{BUILD_NOISY})) {$o->{CONFIG}{BUILD_NOISY} = $config_options->{BUILD_NOISY}}
 
+    if(exists($config_options->{_TESTING})) {$o->{CONFIG}{_TESTING} = $config_options->{_TESTING}} # Internal testing flag
+
     if($config_options->{AUTOWRAP}) {$o->{ILSM}{AUTOWRAP} = 1}
 
     if($config_options->{BOOT}) {$o->{ILSM}{XS}{BOOT} = $config_options->{BOOT}} 
@@ -211,7 +204,7 @@ sub c2xs {
 
     if($config_options->{WRITE_MAKEFILE_PL}) {
       $o->{ILSM}{MAKEFILE}{INC} = $uncorrupted_inc; # Make sure cwd is included only if it was specified.
-      $o->{ILSM}{MAKEFILE}{TYPEMAPS} = \@uncorrupted_typemaps; # Otherwise the standard perl typemap gets included.
+      $o->{ILSM}{MAKEFILE}{TYPEMAPS} = \@uncorrupted_typemaps; # Otherwise the standard perl typemap gets included ... annoying.
       if($config_options->{VERSION}) {$o->{API}{version} = $config_options->{VERSION}}
       else {warn "'VERSION' being set to '0.00' in the Makefile.PL. Did you supply a correct version number to c2xs() ?"}
       print "Writing Makefile.PL in the ", $o->{API}{build_dir}, " directory\n";
@@ -245,10 +238,11 @@ sub _build {
 }
 
 sub _check_config_keys {
-    for('AUTOWRAP', 'AUTO_INCLUDE', 'TYPEMAPS', 'LIBS', 'INC', 'VERSION', 'WRITE_MAKEFILE_PL',
-        'BUILD_NOISY', 'BOOT', 'EXPORT_ALL', 'EXPORT_OK_ALL', 'EXPORT_TAGS_ALL', 'MAKE',
-        'PREFIX', 'CCFLAGS', 'LD', 'LDDLFLAGS', 'MYEXTLIB', 'OPTIMIZE', 'CC', 'USING',
-        'WRITE_PM', 'CODE', 'SRC_LOCATION')
+    for('AUTOWRAP', 'AUTO_INCLUDE', 'CODE', 'TYPEMAPS', 'LIBS', 'INC', 
+        'WRITE_MAKEFILE_PL', 'BUILD_NOISY', 'BOOT', 'EXPORT_ALL', 'EXPORT_OK_ALL',
+        'EXPORT_TAGS_ALL', 'MAKE', 'PREFIX', 'CCFLAGS', 'LD', 'LDDLFLAGS',
+        'MYEXTLIB', 'OPTIMIZE', 'CC', 'SRC_LOCATION', '_TESTING', 'USE', 'USING',
+        'WRITE_PM', 'VERSION',)
        {return 1 if $_ eq $_[0]} # it's a valid config option
     return 0;                    # it's an invalid config option
 }
@@ -258,13 +252,24 @@ sub _write_pm {
     my $offset = 4;
     my $max = 100;
     my $length = $offset;
+    my @use;
+
+    if($config_options->{USE}) {
+      die "Value supplied to config option USE must be an array reference" 
+        if ref($config_options->{USE}) ne 'ARRAY';
+      @use = @{$config_options->{USE}};
+    }
 
     open(WR, '>', $o->{API}{build_dir} . '/' . $o->{API}{modfname} . ".pm")
         or die "Couldn't create the .pm file: $!";
     print "Writing ", $o->{API}{modfname}, ".pm in the ", $o->{API}{build_dir}, " directory\n";
     print WR "## This file generated by InlineX::C2XS (version ",
              $InlineX::C2XS::VERSION, ") using Inline::C (version ", $Inline::C::VERSION, ")\n";
-    print WR "package ", $o->{API}{module}, ";\nuse strict;\n\n";
+    print WR "package ", $o->{API}{module}, ";\n";
+    for(@use) {
+      print WR "use ${_};\n";
+    }
+    print WR "\n";
     print WR "require Exporter;\n*import = \\&Exporter::import;\nrequire DynaLoader;\n\n";
     print WR "\$", $o->{API}{module}, "::VERSION = '", $o->{API}{version}, "';\n\n"; 
     print WR "DynaLoader::bootstrap ", $o->{API}{module}, " \$", $o->{API}{module}, "::VERSION;\n\n";
@@ -604,6 +609,14 @@ InlineX::C2XS - Convert from Inline C code to XS.
     TYPEMAPS =>['my_typemap', 'my_other_typemap'],
   ----
 
+  USE
+   Must be an array reference, listing the modules that the autogenerated
+   pm file needs to load (use). Makes no sense to assign this key if
+   WRITE_PM is not set to a true value. eg:
+
+    USE => ['Digest::MD5', 'LWP::Simple'];
+  ----
+
   USING
    If you want Inline to use ParseRegExp.pm instead of RecDescent.pm for 
    the parsing, then specify either:
@@ -655,7 +668,7 @@ InlineX::C2XS - Convert from Inline C code to XS.
 
   This program is free software; you may redistribute it and/or 
   modify it under the same terms as Perl itself.
-  Copyright 2006-2009, Sisyphus
+  Copyright 2006-2009, 2010,Sisyphus
 
 
 =head1 AUTHOR
